@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #ifndef __PANGO_ENUM_TYPES_H__
 #define __PANGO_ENUM_TYPES_H__
@@ -12,6 +12,11 @@ GType pango_attr_type_get_type (void);
 #define PANGO_TYPE_ATTR_TYPE (pango_attr_type_get_type())
 GType pango_underline_get_type (void);
 #define PANGO_TYPE_UNDERLINE (pango_underline_get_type())
+/* enumerations from "pango-bidi-type.h" */
+GType pango_bidi_type_get_type (void);
+#define PANGO_TYPE_BIDI_TYPE (pango_bidi_type_get_type())
+GType pango_direction_get_type (void);
+#define PANGO_TYPE_DIRECTION (pango_direction_get_type())
 /* enumerations from "pango-coverage.h" */
 GType pango_coverage_level_get_type (void);
 #define PANGO_TYPE_COVERAGE_LEVEL (pango_coverage_level_get_type())
@@ -47,12 +52,9 @@ GType pango_script_get_type (void);
 /* enumerations from "pango-tabs.h" */
 GType pango_tab_align_get_type (void);
 #define PANGO_TYPE_TAB_ALIGN (pango_tab_align_get_type())
-/* enumerations from "pango-types.h" */
-GType pango_direction_get_type (void);
-#define PANGO_TYPE_DIRECTION (pango_direction_get_type())
 G_END_DECLS
 
 #endif /* __PANGO_ENUM_TYPES_H__ */
 
-/* Generated data ends here */
+
 
